# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0

from ..ros_bundle import RosBundle


class RosCatkinBundle(RosBundle):
    """Bundle task for catkin packages."""
